from . import (BindInstanceKeyRequest,CreateKeyPairRequest,DeleteKeyPairRequest,DescribeAvailabilityZonesRequest,DescribeInstancesRequest,DescribeKeyPairsRequest,DescribeZoneAbilityRequest,ImportKeyPairRequest,InquiryInstancePriceHourRequest,InquiryInstancePriceRequest,ModifyInstanceAttributesRequest,ModifyInstanceProjectRequest,ModifyKeyPairRequest,RenewInstanceRequest,ResetInstancePasswordRequest,ResetInstancesRequest,ResizeInstanceHourRequest,RestartInstancesRequest,ReturnInstanceRequest,RunInstancesHourRequest,RunInstancesRequest,StartInstancesRequest,StopInstancesRequest,UnBindInstanceKeyRequest,UpdateInstanceBandwidthHourRequest,UpdateInstanceBandwidthRequest,)
