# -*- coding: utf-8 -*-

from ..qcloudsdkcore.request import Request

class DescribeBmNatGatewayRequest(Request):

    def __init__(self):
        super(DescribeBmNatGatewayRequest, self).__init__(
            'bmvpc', 'qcloudcliV1', 'DescribeBmNatGateway', 'bmvpc.api.qcloud.com')

    def get_limit(self):
        return self.get_params().get('limit')

    def set_limit(self, limit):
        self.add_param('limit', limit)

    def get_natId(self):
        return self.get_params().get('natId')

    def set_natId(self, natId):
        self.add_param('natId', natId)

    def get_natName(self):
        return self.get_params().get('natName')

    def set_natName(self, natName):
        self.add_param('natName', natName)

    def get_offset(self):
        return self.get_params().get('offset')

    def set_offset(self, offset):
        self.add_param('offset', offset)

    def get_orderDirection(self):
        return self.get_params().get('orderDirection')

    def set_orderDirection(self, orderDirection):
        self.add_param('orderDirection', orderDirection)

    def get_orderFeild(self):
        return self.get_params().get('orderFeild')

    def set_orderFeild(self, orderFeild):
        self.add_param('orderFeild', orderFeild)

    def get_unVpcId(self):
        return self.get_params().get('unVpcId')

    def set_unVpcId(self, unVpcId):
        self.add_param('unVpcId', unVpcId)

    def get_vpcId(self):
        return self.get_params().get('vpcId')

    def set_vpcId(self, vpcId):
        self.add_param('vpcId', vpcId)
