# -*- coding: utf-8 -*-

from ..qcloudsdkcore.request import Request

class UpdateInstanceBandwidthRequest(Request):

    def __init__(self):
        super(UpdateInstanceBandwidthRequest, self).__init__(
            'cvm', 'qcloudcliV1', 'UpdateInstanceBandwidth', 'cvm.api.qcloud.com')

    def get_bandwidth(self):
        return self.get_params().get('bandwidth')

    def set_bandwidth(self, bandwidth):
        self.add_param('bandwidth', bandwidth)

    def get_endTime(self):
        return self.get_params().get('endTime')

    def set_endTime(self, endTime):
        self.add_param('endTime', endTime)

    def get_instanceId(self):
        return self.get_params().get('instanceId')

    def set_instanceId(self, instanceId):
        self.add_param('instanceId', instanceId)

    def get_startTime(self):
        return self.get_params().get('startTime')

    def set_startTime(self, startTime):
        self.add_param('startTime', startTime)
