from . import (BuyDeviceRequest,DescribeBmAgentStatusRequest,DescribeBmInstancesRequest,DescribeDeviceClassPartitionRequest,DescribeDeviceClassRequest,DescribeDeviceHardwareInfoRequest,DescribeDeviceInventoryRequest,DescribeDeviceOperationLogRequest,DescribeDevicePartitionRequest,DescribeDevicePositionRequest,DescribeDevicePriceRequest,DescribeDeviceRequest,DescribeHardwareSpecificationRequest,DescribeOsRequest,DescribeRegionsRequest,DescriptionOperationResultRequest,GetDeviceDeployProcessRequest,ModifyDeviceAliasRequest,ModifyDeviceAutoRenewFlagRequest,ModifyPayModePre2PostRequest,OfflineDeviceRequest,QueryElasticPriceRequest,RebootDeviceRequest,ReloadDeviceOsRequest,ResetDevicePasswdRequest,ShutdownDeviceRequest,StartDeviceRequest,)
